"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = adapterErrorHandler;

var _errors = require("../lib/errors");

function adapterErrorHandler(adapter, logger) {
  return Object.keys(adapter).reduce((acc, method) => {
    var _adapter$displayName;

    const name = (0, _errors.capitalize)(method);
    const code = `${(_adapter$displayName = adapter.displayName) !== null && _adapter$displayName !== void 0 ? _adapter$displayName : "ADAPTER"}_${(0, _errors.upperSnake)(name)}`;
    const adapterMethod = adapter[method];

    acc[method] = async (...args) => {
      try {
        logger.debug(code, ...args);
        return await adapterMethod(...args);
      } catch (error) {
        logger.error(`${code}_ERROR`, error);
        const e = new _errors.UnknownError(error);
        e.name = `${name}Error`;
        throw e;
      }
    };

    return acc;
  }, {});
}