"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.withErrorHandling = withErrorHandling;
exports.defaultEvents = void 0;

var _errors = require("../../lib/errors");

const defaultEvents = {
  signIn() {},

  signOut() {},

  createUser() {},

  updateUser() {},

  linkAccount() {},

  session() {}

};
exports.defaultEvents = defaultEvents;

function withErrorHandling(methods, logger) {
  return Object.entries(methods).reduce((acc, [name, method]) => {
    acc[name] = async (...args) => {
      try {
        return await method(...args);
      } catch (e) {
        logger.error(`${(0, _errors.upperSnake)(name)}_EVENT_ERROR`, e);
      }
    };

    return acc;
  }, {});
}